==> kdevelop_5.2.1.orig.tar.xz: kdevelop-5.2.1/plugins/qmljs/codecompletion/worker.h <==
/*
 * This file is part of qmljs, the QML/JS language support plugin for KDevelop
 * Copyright (c) 2013 Sven Brauch <svenbrauch@googlemail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef QMLJS_WORKER_H
#define QMLJS_WORKER_H

#include <language/codecompletion/codecompletionworker.h>
#include <language/codecompletion/codecompletionmodel.h>

namespace QmlJS {

class CodeCompletionWorker : public KDevelop::CodeCompletionWorker
{
public:
    explicit CodeCompletionWorker(KDevelop::CodeCompletionModel* model);

protected:
    virtual KDevelop::CodeCompletionContext* createCompletionContext(
        KDevelop::DUContextPointer context, const QString& contextText,
        const QString& followingText, const KDevelop::CursorInRevision& position) const override;
};

}

#endif // QMLJS_WORKER_H

==> kdevelop-5.4.80.tar.xz: kdevelop-5.4.80/plugins/qmljs/codecompletion/worker.h <==
/*
 * This file is part of qmljs, the QML/JS language support plugin for KDevelop
 * Copyright (c) 2013 Sven Brauch <svenbrauch@googlemail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef QMLJS_WORKER_H
#define QMLJS_WORKER_H

#include <language/codecompletion/codecompletionworker.h>
#include <language/codecompletion/codecompletionmodel.h>

namespace QmlJS {

class CodeCompletionWorker : public KDevelop::CodeCompletionWorker
{
    Q_OBJECT
public:
    explicit CodeCompletionWorker(KDevelop::CodeCompletionModel* model);

protected:
    KDevelop::CodeCompletionContext* createCompletionContext(
        const KDevelop::DUContextPointer& context, const QString& contextText,
        const QString& followingText, const KDevelop::CursorInRevision& position) const override;
};

}

#endif // QMLJS_WORKER_H
